@@ -28,7 +28,7 @@
 #'  setting \code{`min_dims`} to \code{2} will use both the index and the values as columns.
 #' @param overwrite Whether to allow overwriting of existing columns. (Logical)
 #' @keywords internal
-rearrr_fn_ <- function(data, origin_fn, check_fn, allowed_types, force_df, min_dims){
+rearrr_fn_ <- function(data, origin_fn, check_fn, allowed_types, force_df, min_dims, overwrite){
   stop("'rearrr_fn' should not be called. Is used for documentation only.")
 }
 
